==> 1.0.2_20240315_release.zip: app/service/admin/S_article.php <==
<?php

namespace app\service\admin;

use app\db\admin\D_article;

class S_article
{
    public $d_article;

    public function __construct()
    {
        $this->d_article = new D_article();
    }

    /**
     * 文章列表数据
     * @param string $paramObj
     * @return array
     */
    public function listData($paramObj=""){
        return $this->d_article->listData($paramObj);
    }

    /**
     * 获取数据详情
     * @param string $paramObj
     * @return array
     */
    public function info($paramObj=""){
        return $this->d_article->info($paramObj);
    }

    /**
     * 更新 linkurl 数据
     * @param string $paramObj
     * @return array
     */
    public function updateLinkurl($paramObj=""){
        return $this->d_article->updateLinkurl($paramObj);
    }

    /**
     * 创建数据
     * @param string $paramObj
     * @return array
     */
    public function store($paramObj=""){
        return $this->d_article->store($paramObj);
    }

    /**
     * 更新数据
     * @param string $paramObj
     * @return array
     */
    public function update($paramObj=""){
        return $this->d_article->update($paramObj);
    }

    /**
     * 删除数据
     * @param string $paramObj
     * @return array
     */
    public function delete($paramObj=""){
        return $this->d_article->delete($paramObj);
    }

    public function __call($name,$arguments)
    {
        return recordLogMsgLevelTwo(app("errorLevel")::E_WARNING,app("errorCode")::UNDEFINED_METHOD,lang("sys.noMethodDefined"),$name,$arguments);
    }
}

==> 1.0.20_20240718_release.zip: app/service/admin/S_article.php <==
<?php

namespace app\service\admin;

use app\db\admin\D_article;

class S_article
{
    public $d_article;

    public function __construct()
    {
        $this->d_article = new D_article();
    }

    /**
     * 获取进度
     * @param string $paramObj
     * @return array
     */
    public function getProccess($paramObj=""){
        return $this->d_article->getProccess($paramObj);
    }

    /**
     * 获取位置信息
     * @param string $paramObj
     * @return array
     */
    public function getPositionData($paramObj=""){
        return $this->d_article->getPositionData($paramObj);
    }

    /**
     * 文章列表数据
     * @param string $paramObj
     * @return array
     */
    public function listData($paramObj=""){
        return $this->d_article->listData($paramObj);
    }

    /**
     * 获取文章数据
     * @param string $paramObj
     * @return array
     */
    public function getAllData($paramObj=""){
        return $this->d_article->getAllData($paramObj);
    }

    /**
     * 获取数据详情
     * @param string $paramObj
     * @return array
     */
    public function info($paramObj=""){
        return $this->d_article->info($paramObj);
    }

    /**
     * 更新 linkurl 数据
     * @param string $paramObj
     * @return array
     */
    public function updateLinkurl($paramObj=""){
        return $this->d_article->updateLinkurl($paramObj);
    }

    /**
     * 创建数据
     * @param string $paramObj
     * @return array
     */
    public function store($paramObj=""){
        return $this->d_article->store($paramObj);
    }

    /**
     * 更新数据
     * @param string $paramObj
     * @return array
     */
    public function update($paramObj=""){
        return $this->d_article->update($paramObj);
    }

    /**
     * 删除数据
     * @param string $paramObj
     * @return array
     */
    public function delete($paramObj=""){
        return $this->d_article->delete($paramObj);
    }

    public function __call($name,$arguments)
    {
        return recordLogMsgLevelTwo(app("errorLevel")::E_WARNING,app("errorCode")::UNDEFINED_METHOD,lang("sys.noMethodDefined"),$name,$arguments);
    }
}
